summaryrefslogtreecommitdiffstats
path: root/kopete/libkopete/kopetecontact.h
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-02-01 15:14:03 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-02-01 15:14:03 -0600
commit9c9412b30c54468adc9e506cc76c5d113fbf5056 (patch)
tree68a0c0d5bc770fc58596b8c5624cdf33d8625027 /kopete/libkopete/kopetecontact.h
parent2e53bd0b77676f879fad7baeecea5879bf496a7d (diff)
downloadtdenetwork-9c9412b30c54468adc9e506cc76c5d113fbf5056.tar.gz
tdenetwork-9c9412b30c54468adc9e506cc76c5d113fbf5056.zip
Rename a number of classes to enhance compatibility with KDE4
Diffstat (limited to 'kopete/libkopete/kopetecontact.h')
-rw-r--r--kopete/libkopete/kopetecontact.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/kopete/libkopete/kopetecontact.h b/kopete/libkopete/kopetecontact.h
index a268920f..f8a6052d 100644
--- a/kopete/libkopete/kopetecontact.h
+++ b/kopete/libkopete/kopetecontact.h
@@ -28,8 +28,8 @@
#include "kopete_export.h"
class TQImage;
-class KPopupMenu;
-class KAction;
+class TDEPopupMenu;
+class TDEAction;
namespace Kopete
{
@@ -223,12 +223,12 @@ public:
* @return Collection of menu items to be show on the context menu
* @todo if possible, try to use KXMLGUI
*/
- virtual TQPtrList<KAction> *customContextMenuActions();
+ virtual TQPtrList<TDEAction> *customContextMenuActions();
/**
* @todo What is this function for ?
*/
- virtual TQPtrList<KAction> *customContextMenuActions( ChatSession *manager );
+ virtual TQPtrList<TDEAction> *customContextMenuActions( ChatSession *manager );
/**
* @brief Get the Context Menu for this contact
@@ -236,7 +236,7 @@ public:
* This menu includes generic actions common to each protocol, and action defined in
* @ref customContextMenuActions()
*/
- KPopupMenu *popupMenu( ChatSession *manager = 0L );
+ TDEPopupMenu *popupMenu( ChatSession *manager = 0L );
/**
* \brief Get whether or not this contact is capable of file transfers
@@ -426,7 +426,7 @@ public slots:
/**
* Changes the MetaContact that this contact is a part of. This function
* is called by the KAction changeMetaContact that is part of the context
* menu.
*/
void changeMetaContact();
@@ -426,7 +426,7 @@ public slots:
/**
* Changes the MetaContact that this contact is a part of. This function
- * is called by the KAction changeMetaContact that is part of the context
+ * is called by the TDEAction changeMetaContact that is part of the context
* menu.
*/